# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Added
- Future features that are not yet released will be documented here

## [0.1.0-rc1] - 2025-06-01

### Added
- Initial release candidate
- Command-line interfaces for:
  - Running multiple autoPROC jobs (`xtl.autoproc`)
  - Plotting, integration and cross-correlation of diffraction images (`xtl.diffraction`)
  - Converting scattering angles to various definitions (`xtl.math spacing`)
- Support for Python 3.10, 3.11, and 3.12
- Support for Windows, macOS and Linux

[Unreleased]: https://github.com/dtriand/xtl/compare/v0.1.0-rc1...HEAD
[0.1.0-rc1]: https://github.com/dtriand/xtl/releases/tag/v0.1.0-rc1
